// Package importer implements utilities used to create DMS3 DAGs from files
// and readers.
package importer

import (
	bal "gitlab.dms3.io/dms3/go-unixfs/importer/balanced"
	h "gitlab.dms3.io/dms3/go-unixfs/importer/helpers"
	trickle "gitlab.dms3.io/dms3/go-unixfs/importer/trickle"

	chunker "gitlab.dms3.io/dms3/go-dms3-chunker"
	ld "gitlab.dms3.io/dms3/go-ld-format"
)

// BuildDagFromReader creates a DAG given a DAGService and a Splitter
// implementation (Splitters are io.Readers), using a Balanced layout.
func BuildDagFromReader(ds ld.DAGService, spl chunker.Splitter) (ld.Node, error) {
	dbp := h.DagBuilderParams{
		Dagserv:  ds,
		Maxlinks: h.DefaultLinksPerBlock,
	}
	db, err := dbp.New(spl)
	if err != nil {
		return nil, err
	}
	return bal.Layout(db)
}

// BuildTrickleDagFromReader creates a DAG given a DAGService and a Splitter
// implementation (Splitters are io.Readers), using a Trickle Layout.
func BuildTrickleDagFromReader(ds ld.DAGService, spl chunker.Splitter) (ld.Node, error) {
	dbp := h.DagBuilderParams{
		Dagserv:  ds,
		Maxlinks: h.DefaultLinksPerBlock,
	}

	db, err := dbp.New(spl)
	if err != nil {
		return nil, err
	}
	return trickle.Layout(db)
}
